package at.hl.okb;

import java.util.List;
import java.util.Map;

import at.hl.wsclient.okb.AlgorithmParameter;

/**
 * Interface for ECJ Connector
 * @author HolperM
 *
 */
public interface IECJConnector {
	
	/**
	 * checks if algorithm exists and returns AlgorithmParameterMap with AlgorithmParamName, AlgorithParamType
	 * @param algorithmName
	 * @param algorithmClassId
	 * @param platformId
	 * @param algorithParameterName
	 * @return
	 * @throws Exception
	 */
	public Map<String,AlgorithmParameter> initializeAlgorithm(String algorithmName, String algorithmClassId,
		    String platformId, Iterable<String> algorithmParameterName) throws Exception;
	
	/**
	 * Does some logical Check against HL
	 * create missing Datatypes (if not found)
	 * saves algorithmParams, problemParams into HL
	 * 
	 * @param algorithm Name of the Algorithm
	 * @param platform Name of the Platform
	 * @param problem Name of the Problem
	 * @param algoParams map<AlgoParamname, Paramvalue> (as JavaType)
	 * @param problemParams map<problemParamName, Paramvalue> (as JavaType)
	 * @param paramFile as Object (will be saved as BLOB)
	 * @throws Exception
	 */
	public void initialize(String algorithm, String platform, String problem, Map<String, Object> algoParams, Map<String,Object> problemParams, Object paramFile) throws Exception;

	/**
	 * delivers Results to HL
	 * @param resultList
	 * @throws Exception
	 */
	public void result(List<Object> resultList) throws Exception;
}
